#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys

from ruamel.yaml import YAML

import otc_metadata.services
import argparse


def main():
    parser = argparse.ArgumentParser(
        description="Generate Metadata for doc-exports."
    )
    parser.add_argument(
        "--cloud-environment",
        required=True,
        default="eu_de",
        help="Cloud Environment. Default: eu_de",
    )

    args = parser.parse_args()
    data = otc_metadata.services.Services()
    data._sort_data()

    docs = data.docs_html_by_category(environment="internal",cloud_environment=args.cloud_environment)

    # Filter out documents with "disable_import": True
    for category, services in docs['categories'].items():
        for service in services:
            filtered_docs = []

            for doc in service['docs']:
                # Check if the document doesnt have 'disable_import' on True
                if not doc.get('disable_import'):
                    filtered_docs.append(doc)

            service['docs'] = filtered_docs

    _yaml = YAML()
    _yaml.indent(mapping=2, sequence=4, offset=2)
    sys.stdout.write(
        "# Auto-generated by otc_metadata.generate_docexports.data\n"
    )
    _yaml.dump(docs, sys.stdout)


if __name__ == "__main__":
    main()
